==> cutenews_1.0.0.tar.gz: cutenews-1.0.0/src/plugins/externalfeedplugin.cpp <==
/*
 * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "externalfeedplugin.h"
#include "externalenclosurerequest.h"
#include "externalfeedrequest.h"

ExternalFeedPlugin::ExternalFeedPlugin(QObject *parent) :
    QObject(parent),
    FeedPlugin()
{
}

ExternalFeedPlugin::ExternalFeedPlugin(const QString &id, const QString &fileName, QObject *parent) :
    QObject(parent),
    FeedPlugin(),
    m_fileName(fileName),
    m_id(id)
{
}

QString ExternalFeedPlugin::fileName() const {
    return m_fileName;
}

void ExternalFeedPlugin::setFileName(const QString &fileName) {
    m_fileName = fileName;
}

QString ExternalFeedPlugin::id() const {
    return m_id;
}

void ExternalFeedPlugin::setId(const QString &id) {
    m_id = id;
}

EnclosureRequest* ExternalFeedPlugin::enclosureRequest(QObject *parent) {
    return new ExternalEnclosureRequest(id(), fileName(), parent);
}

FeedRequest* ExternalFeedPlugin::feedRequest(QObject *parent) {
    return new ExternalFeedRequest(id(), fileName(), parent);
}

==> cutenews_1.2.0.tar.gz: cutenews-1.2.0/src/plugins/externalfeedplugin.cpp <==
/*
 * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "externalfeedplugin.h"
#include "externalarticlerequest.h"
#include "externalenclosurerequest.h"
#include "externalfeedrequest.h"

ExternalFeedPlugin::ExternalFeedPlugin(QObject *parent) :
    QObject(parent),
    FeedPlugin()
{
}

ExternalFeedPlugin::ExternalFeedPlugin(const QString &id, const QString &fileName, QObject *parent) :
    QObject(parent),
    FeedPlugin(),
    m_fileName(fileName),
    m_id(id)
{
}

QString ExternalFeedPlugin::fileName() const {
    return m_fileName;
}

void ExternalFeedPlugin::setFileName(const QString &fileName) {
    m_fileName = fileName;
}

QString ExternalFeedPlugin::id() const {
    return m_id;
}

void ExternalFeedPlugin::setId(const QString &id) {
    m_id = id;
}

ArticleRequest* ExternalFeedPlugin::articleRequest(QObject *parent) {
    return new ExternalArticleRequest(id(), fileName(), parent);
}

EnclosureRequest* ExternalFeedPlugin::enclosureRequest(QObject *parent) {
    return new ExternalEnclosureRequest(id(), fileName(), parent);
}

FeedRequest* ExternalFeedPlugin::feedRequest(QObject *parent) {
    return new ExternalFeedRequest(id(), fileName(), parent);
}
